@@ -2,10 +2,10 @@
 require File.expand_path("../helper", __FILE__)
 require "stringio"
 
-class TestTraceOutput < Rake::TestCase
+class TestTraceOutput < Rake::TestCase # :nodoc:
   include Rake::TraceOutput
 
-  class PrintSpy
+  class PrintSpy # :nodoc:
     attr_reader :result, :calls
 
     def initialize
